import React, { Component } from 'react';
import { Typography, Paper, createMuiTheme, MuiThemeProvider, TableCell, FormControlLabel, TextField, Input, Tooltip, withStyles, Snackbar } from '@material-ui/core';
import MUIDataTable from 'mui-datatables';
import NumberFormat from 'react-number-format';
import api from '../../api';
import AddIcon from '@material-ui/icons/Add';
import { values } from 'ramda';
import PropagateLoader from "react-spinners/PropagateLoader"
import Images from '../../assets/Images';
import ReactTooltip from 'react-tooltip';
import UploadFile from "../../library/Upload";
import { ExcelRenderer } from 'react-excel-renderer';
import { Alert } from '@material-ui/lab';
import * as R from 'ramda';

const LightTooltip = withStyles((theme) => ({
    tooltip: {
        backgroundColor: theme.palette.common.white,
        color: 'rgba(0, 0, 0, 0.87)',
        boxShadow: theme.shadows[1],
        fontSize: 11,
    },
}))(Tooltip);

var ct = require("../../library/CustomTable");
const getMuiTheme = () => createMuiTheme(ct.customTable3());

const options = ct.customOptionsFixedColumn();
const style = {
    position: "sticky",
    left: 0,
    zIndex: 101,
    background: "white",
};
const style2 = {
    position: "sticky",
    background: "white",
    zIndex: 100,
    top: 0
};

export default class TaxPlanning extends Component {
    constructor(props) {
        super(props)
        this.state = {
            dataTable: [],
            visibleTP: true,
            disabledSave: true,
            editable: false,
            buttonError: false,
            judulColumn: null,
            updateBy: '-',
            buttonDraft: true,
            handleTekTekTek: 0

        }
        this.handleValue = this.handleValue.bind(this)
        this.fileHandler = this.fileHandler.bind(this);
    }

    componentDidMount() {
        this.getItemHierarki()
        this.getLatestUpdate()
        console.log(this.props);
    }

    getLatestUpdate() {
        let payload = {
            "report_id": this.props.report_id,
            "revision": Number(this.props.revision),
            "periode": this.props.periode,
            "company_id": this.props.company.company_id,
            "submission_id": this.props.submissionID
        }
        api.create().getLastestUpdateMB(payload).then(response => {
            if (response.data) {
                if (response.data.status === "success") {
                    this.setState({
                        updateBy: response.data.data.latest_update === null ? '-' : response.data.data.latest_update
                    })
                }
            }
        })
    }

    getItemHierarki() {
        this.setState({ loading: true, judulColumn: null })
        let payload = {
            "report_id": this.props.report_id,
            "revision": Number(this.props.revision),
            "periode": this.props.periode,
            "company_id": this.props.company.company_id,
            "submission_id": this.props.submissionID
        }
        api.create().getDetailReportMB(payload).then(response => {
            console.log(response);
            let dataTable = []
            if (response.data) {
                let res = response.data.data
                const handlePushChild = (item) => {
                    let indexIDzz = dataTable.findIndex((val) => val[1] === item.id)
                    if (indexIDzz === -1) {
                        dataTable.push([
                            item.type_report_id,
                            item.type_report_tax.value_tbc.type_report_id,
                            item.type_report_tax.value_fc.type_report_id,
                            item.type_report_tax.value_tbf.type_report_id,
                            item.id,
                            item.parent,
                            {tbc : item.formula_tax.value_tbc, fcp: item.formula_tax.value_fc, tbf: item.formula_tax.value_tbf },
                            item.level,
                            item.description,
                            {tbc : item.tax_planning.january.tbc, fcp: item.tax_planning.january.fcp, tbf: item.tax_planning.january.tbf},
                            {tbc : item.tax_planning.february.tbc, fcp: item.tax_planning.february.fcp, tbf: item.tax_planning.february.tbf},
                            {tbc : item.tax_planning.march.tbc, fcp: item.tax_planning.march.fcp, tbf: item.tax_planning.march.tbf},
                            {tbc : item.tax_planning.april.tbc, fcp: item.tax_planning.april.fcp, tbf: item.tax_planning.april.tbf},
                            {tbc : item.tax_planning.may.tbc, fcp: item.tax_planning.may.fcp, tbf: item.tax_planning.may.tbf},
                            {tbc : item.tax_planning.june.tbc, fcp: item.tax_planning.june.fcp, tbf: item.tax_planning.june.tbf},
                            {tbc : item.tax_planning.july.tbc, fcp: item.tax_planning.july.fcp, tbf: item.tax_planning.july.tbf},
                            {tbc : item.tax_planning.august.tbc === null ? "0" : item.tax_planning.august.tbc === "" ? "0" : item.tax_planning.august.tbc, 
                                fcp: item.tax_planning.august.fcp, tbf: item.tax_planning.august.tbf},
                            {tbc : item.tax_planning.september.tbc, fcp: item.tax_planning.september.fcp, tbf: item.tax_planning.september.tbf},
                            {tbc : item.tax_planning.october.tbc, fcp: item.tax_planning.october.fcp, tbf: item.tax_planning.october.tbf},
                            {tbc : item.tax_planning.november.tbc, fcp: item.tax_planning.november.fcp, tbf: item.tax_planning.november.tbf},
                            {tbc : item.tax_planning.december.tbc, fcp: item.tax_planning.december.fcp, tbf: item.tax_planning.december.tbf},
                            item.tax_planning.total_current_year,
                            {tbc : item.tax_planning.total_next_year.tbc, fcp: item.tax_planning.total_next_year.fcp, tbf: item.tax_planning.total_next_year.tbf},
                            {tbc : item.tax_planning.total_more_year.tbc, fcp: item.tax_planning.total_more_year.fcp, tbf: item.tax_planning.total_more_year.tbf},
                            item.order
                        ])
                    }
                    if (item.children !== null) {
                        if (item.children.length > 0) {
                            item.children.map((items, indexs) => {
                                handlePushChild(items)
                            })
                        }
                    }  
                }
                res.map((item, index) => {
                    dataTable.push([  
                        item.type_report_id,
                        item.type_report_tax.value_tbc.type_report_id,
                        item.type_report_tax.value_fc.type_report_id,
                        item.type_report_tax.value_tbf.type_report_id,
                        item.id,
                        item.parent,
                        {tbc : item.formula_tax.value_tbc, fcp: item.formula_tax.value_fc, tbf: item.formula_tax.value_tbf },
                        item.level,
                        item.description,
                        {tbc : item.tax_planning.january.tbc, fcp: item.tax_planning.january.fcp, tbf: item.tax_planning.january.tbf},
                        {tbc : item.tax_planning.february.tbc, fcp: item.tax_planning.february.fcp, tbf: item.tax_planning.february.tbf},
                        {tbc : item.tax_planning.march.tbc, fcp: item.tax_planning.march.fcp, tbf: item.tax_planning.march.tbf},
                        {tbc : item.tax_planning.april.tbc, fcp: item.tax_planning.april.fcp, tbf: item.tax_planning.april.tbf},
                        {tbc : item.tax_planning.may.tbc, fcp: item.tax_planning.may.fcp, tbf: item.tax_planning.may.tbf},
                        {tbc : item.tax_planning.june.tbc, fcp: item.tax_planning.june.fcp, tbf: item.tax_planning.june.tbf},
                        {tbc : item.tax_planning.july.tbc, fcp: item.tax_planning.july.fcp, tbf: item.tax_planning.july.tbf},
                        {tbc : item.tax_planning.august.tbc === null ? "0" : item.tax_planning.august.tbc === "" ? "0" : item.tax_planning.august.tbc, 
                            fcp: item.tax_planning.august.fcp, tbf: item.tax_planning.august.tbf},
                        {tbc : item.tax_planning.september.tbc, fcp: item.tax_planning.september.fcp, tbf: item.tax_planning.september.tbf},
                        {tbc : item.tax_planning.october.tbc, fcp: item.tax_planning.october.fcp, tbf: item.tax_planning.october.tbf},
                        {tbc : item.tax_planning.november.tbc, fcp: item.tax_planning.november.fcp, tbf: item.tax_planning.november.tbf},
                        {tbc : item.tax_planning.december.tbc, fcp: item.tax_planning.december.fcp, tbf: item.tax_planning.december.tbf},
                        item.tax_planning.total_current_year,
                        {tbc : item.tax_planning.total_next_year.tbc, fcp: item.tax_planning.total_next_year.fcp, tbf: item.tax_planning.total_next_year.tbf},
                        {tbc : item.tax_planning.total_more_year.tbc, fcp: item.tax_planning.total_more_year.fcp, tbf: item.tax_planning.total_more_year.tbf},
                        item.order
                    ])
                    if (item.children !== null) {
                        if (item.children.length > 0) {
                            item.children.map((items, indexs) => {
                                handlePushChild(items)
                            })
                        }
                    }
                })
                this.setState({ dataTable, loading: false, buttonError: true, editable: true })
            } else {
                this.setState({ dataTable, loading: false, buttonError: true, editable: true })   
            }
        })
    }

    handleValue(data) {
        let total = 0
        this.state.dataTable.map((item, index) => {
            if (data.rowData[4] == item[5]) {
                total = item[data.columnIndex] == undefined ? (Number(total) + 0) : (Number(total) + Number(item[data.columnIndex]))
            }
        })
        let indexParent = this.state.dataTable.findIndex((val) => val[4] === this.state.dataTable[data.rowIndex][5])
        let a = this.state.dataTable[data.rowIndex][data.columnIndex] = total
        // console.log(indexParent);
        return a
    }

    handleChange(value, tableMeta) {
        let val = String(value).split(",").join("")
        let data = this.state.dataTable
        let indexParent = data.findIndex((val) => val[4] === data[tableMeta.rowIndex][5])
        if (indexParent > 0) {
            // console.log(indexParent)
            let a = data[tableMeta.rowIndex][tableMeta.columnIndex] = Number(val)
            let jagain = data[indexParent][tableMeta.columnIndex]
            a = data[indexParent][tableMeta.columnIndex] = jagain == undefined ? (0 + Number(val)) : (jagain + Number(val))
        } else {
            data[tableMeta.rowIndex][tableMeta.columnIndex] = Number(val)
        }
        // this.forceUpdate()
        // console.log(this.state.dataTable)
        // this.setState({
        //     data: a,
        // }, () => console.log(this.state.dataTable))
    }

    backToMasterBudget(type) {
        let data = []
        this.state.dataTable.map(i => {
            data.push({
                item_report_id: i[4],
                january: {
                    tbc: String(Number(i[9].tbc).toFixed(1)),
                    fcp: String(Number(i[9].fcp).toFixed(1)),
                    tbf: String(Number(i[9].tbf).toFixed(1))
                },
                february: {
                    tbc: String(Number(i[10].tbc).toFixed(1)),
                    fcp: String(Number(i[10].fcp).toFixed(1)),
                    tbf: String(Number(i[10].tbf).toFixed(1))
                },
                march: {
                    tbc: String(Number(i[11].tbc).toFixed(1)),
                    fcp: String(Number(i[11].fcp).toFixed(1)),
                    tbf: String(Number(i[11].tbf).toFixed(1))
                },
                april: {
                    tbc: String(Number(i[12].tbc).toFixed(1)),
                    fcp: String(Number(i[12].fcp).toFixed(1)),
                    tbf: String(Number(i[12].tbf).toFixed(1))
                },
                may: {
                    tbc: String(Number(i[13].tbc).toFixed(1)),
                    fcp: String(Number(i[13].fcp).toFixed(1)),
                    tbf: String(Number(i[13].tbf).toFixed(1))
                },
                june: {
                    tbc: String(Number(i[14].tbc).toFixed(1)),
                    fcp: String(Number(i[14].fcp).toFixed(1)),
                    tbf: String(Number(i[14].tbf).toFixed(1))
                },
                july: {
                    tbc: String(Number(i[15].tbc).toFixed(1)),
                    fcp: String(Number(i[15].fcp).toFixed(1)),
                    tbf: String(Number(i[15].tbf).toFixed(1))
                },
                august: {
                    tbc: String(Number(i[16].tbc).toFixed(1)),
                    fcp: String(Number(i[16].fcp).toFixed(1)),
                    tbf: String(Number(i[16].tbf).toFixed(1))
                },
                september: {
                    tbc: String(Number(i[17].tbc).toFixed(1)),
                    fcp: String(Number(i[17].fcp).toFixed(1)),
                    tbf: String(Number(i[17].tbf).toFixed(1))
                },
                october: {
                    tbc: String(Number(i[18].tbc).toFixed(1)),
                    fcp: String(Number(i[18].fcp).toFixed(1)),
                    tbf: String(Number(i[18].tbf).toFixed(1))
                },
                november: {
                    tbc: String(Number(i[19].tbc).toFixed(1)),
                    fcp: String(Number(i[19].fcp).toFixed(1)),
                    tbf: String(Number(i[19].tbf).toFixed(1))
                },
                december: {
                    tbc: String(Number(i[20].tbc).toFixed(1)),
                    fcp: String(Number(i[20].fcp).toFixed(1)),
                    tbf: String(Number(i[20].tbf).toFixed(1))
                },
                total_current_year: String(Number(i[21]).toFixed(1)),
                total_next_year: {
                    tbc: String(Number(i[22].tbc).toFixed(1)),
                    fcp: String(Number(i[22].fcp).toFixed(1)),
                    tbf: String(Number(i[22].tbf).toFixed(1))
                },
                total_more_year: {
                    tbc: String(Number(i[23].tbc).toFixed(1)),
                    fcp: String(Number(i[23].fcp).toFixed(1)),
                    tbf: String(Number(i[23].tbf).toFixed(1))
                }
            })
        })
        let payload = {
            "submission_id": this.props.submissionID,
            "company_id": this.props.company.company_id,
            "periode": this.props.periode,
            "report_id": this.props.report_id,
            "status": type,
            "tax_planning": data
        }
        // console.log(JSON.stringify(payload));
        this.props.saveToMasterBudget(payload)
        this.props.onClickClose()
    }

    fileHandler = (event) => {
        let fileObj = event
        ExcelRenderer(fileObj, (err, resp) => {
            // console.log(resp)
            if (err) {
                console.log(err);
            }
            else {
                let isi = resp.rows.slice(4)
                console.log(resp.rows[2]);
                console.log(resp.rows);
                let payload = []
                let reg = /^[-+]?(?:[0-9]+,)*[0-9]+(?:\.[0-9]+)?$/;
                isi.map((i, index) => {
                    if (i.length > 0) {
                        payload.push({
                            item_report_id: i[0] === undefined ? "" : String(i[0]).trim(),
                            item_report: i[1] === undefined ? "" : String(i[1]).trim(),
                            january: {
                                tbc: i[2] === undefined ? "0" : reg.test(String(i[2])) === false ? "0" : String(i[2]).trim(),
                                fcp: i[3] === undefined ? "0" : reg.test(String(i[3])) === false ? "0" : String(i[3]).trim(),
                                tbf: i[4] === undefined ? "0" : reg.test(String(i[4])) === false ? "0" : String(i[4]).trim(),
                            },
                            february: {
                                tbc: i[5] === undefined ? "0" : reg.test(String(i[5])) === false ? "0" : String(i[5]).trim(),
                                fcp: i[6] === undefined ? "0" : reg.test(String(i[6])) === false ? "0" : String(i[6]).trim(),
                                tbf: i[7] === undefined ? "0" : reg.test(String(i[7])) === false ? "0" : String(i[7]).trim(),
                            },
                            march: {
                                tbc: i[8] === undefined ? "0" : reg.test(String(i[8])) === false ? "0" : String(i[8]).trim(),
                                fcp: i[9] === undefined ? "0" : reg.test(String(i[9])) === false ? "0" : String(i[9]).trim(),
                                tbf: i[10] === undefined ? "0" : reg.test(String(i[10])) === false ? "0" : String(i[10]).trim(),
                            },
                            april: {
                                tbc: i[11] === undefined ? "0" : reg.test(String(i[11])) === false ? "0" : String(i[11]).trim(),
                                fcp: i[12] === undefined ? "0" : reg.test(String(i[12])) === false ? "0" : String(i[12]).trim(),
                                tbf: i[13] === undefined ? "0" : reg.test(String(i[13])) === false ? "0" : String(i[13]).trim(),
                            },
                            may: {
                                tbc: i[14] === undefined ? "0" : reg.test(String(i[14])) === false ? "0" : String(i[14]).trim(),
                                fcp: i[15] === undefined ? "0" : reg.test(String(i[15])) === false ? "0" : String(i[15]).trim(),
                                tbf: i[16] === undefined ? "0" : reg.test(String(i[16])) === false ? "0" : String(i[16]).trim(),
                            },
                            june: {
                                tbc: i[17] === undefined ? "0" : reg.test(String(i[17])) === false ? "0" : String(i[17]).trim(),
                                fcp: i[18] === undefined ? "0" : reg.test(String(i[18])) === false ? "0" : String(i[18]).trim(),
                                tbf: i[19] === undefined ? "0" : reg.test(String(i[19])) === false ? "0" : String(i[19]).trim(),
                            },
                            july: {
                                tbc: i[20] === undefined ? "0" : reg.test(String(i[20])) === false ? "0" : String(i[20]).trim(),
                                fcp: i[21] === undefined ? "0" : reg.test(String(i[21])) === false ? "0" : String(i[21]).trim(),
                                tbf: i[22] === undefined ? "0" : reg.test(String(i[22])) === false ? "0" : String(i[22]).trim(),
                            },
                            august: {
                                tbc: i[23] === undefined ? "0" : reg.test(String(i[23])) === false ? "0" : String(i[23]).trim(),
                                fcp: i[24] === undefined ? "0" : reg.test(String(i[24])) === false ? "0" : String(i[24]).trim(),
                                tbf: i[25] === undefined ? "0" : reg.test(String(i[25])) === false ? "0" : String(i[25]).trim(),
                            },
                            september: {
                                tbc: i[26] === undefined ? "0" : reg.test(String(i[26])) === false ? "0" : String(i[26]).trim(),
                                fcp: i[27] === undefined ? "0" : reg.test(String(i[27])) === false ? "0" : String(i[27]).trim(),
                                tbf: i[28] === undefined ? "0" : reg.test(String(i[28])) === false ? "0" : String(i[28]).trim(),
                            },
                            october: {
                                tbc: i[29] === undefined ? "0" : reg.test(String(i[29])) === false ? "0" : String(i[29]).trim(),
                                fcp: i[30] === undefined ? "0" : reg.test(String(i[30])) === false ? "0" : String(i[30]).trim(),
                                tbf: i[31] === undefined ? "0" : reg.test(String(i[31])) === false ? "0" : String(i[31]).trim(),
                            },
                            november: {
                                tbc: i[32] === undefined ? "0" : reg.test(String(i[32])) === false ? "0" : String(i[32]).trim(),
                                fcp: i[33] === undefined ? "0" : reg.test(String(i[33])) === false ? "0" : String(i[33]).trim(),
                                tbf: i[34] === undefined ? "0" : reg.test(String(i[34])) === false ? "0" : String(i[34]).trim(),
                            },
                            december: {
                                tbc: i[35] === undefined ? "0" : reg.test(String(i[35])) === false ? "0" : String(i[35]).trim(),
                                fcp: i[36] === undefined ? "0" : reg.test(String(i[36])) === false ? "0" : String(i[36]).trim(),
                                tbf: i[37] === undefined ? "0" : reg.test(String(i[37])) === false ? "0" : String(i[37]).trim(),
                            },
                            total_current_year: i[38] === undefined ? "" : String(i[38]).trim(),
                            total_next_year: {
                                tbc: i[39] === undefined ? "0" : reg.test(String(i[39])) === false ? "0" : String(i[39]).trim(),
                                fcp: i[40] === undefined ? "0" : reg.test(String(i[40])) === false ? "0" : String(i[40]).trim(),
                                tbf: i[41] === undefined ? "0" : reg.test(String(i[41])) === false ? "0" : String(i[41]).trim(),
                            },
                            total_more_year: {
                                tbc: i[42] === undefined ? "0" : reg.test(String(i[42])) === false ? "0" : String(i[42]).trim(),
                                fcp: i[43] === undefined ? "0" : reg.test(String(i[43])) === false ? "0" : String(i[43]).trim(),
                                tbf: i[44] === undefined ? "0" : reg.test(String(i[44])) === false ? "0" : String(i[44]).trim(),
                            }
                        })
                    }
                })
                let body = {
                    company_id: this.props.company.company_id,
                    periode: this.props.periode,
                    report_id: this.props.report_id,
                    tax_planning: payload
                }
                this.setState({ payload: body, judul: resp.rows[1][0], judulColumn: resp.rows[2] })
                console.log(this.state.judulColumn)
            }
        });
    }

    checkUpload() {
        api.create().checkUploadMB(this.state.payload).then(response => {
            console.log(JSON.stringify(this.state.payload));
            console.log(response)
            if (response.data) {
                if (response.data.status === 'success') {
                    this.setState({ visibleUpload: false, visibleTP: false, loading: true })
                    let dataTable = response.data.data.map((item, index) => {
                        return [
                            // item.type_report_id,
                            0,
                            Number(item.type_report_id.tbc), 
                            Number(item.type_report_id.fcp), 
                            Number(item.type_report_id.tbf),
                            item.item_report_id,
                            item.parent,
                            item.formula,
                            // {tbc: item.formula.tbc, fcp: item.formula.fcp, tbf: item.formula.tbf},
                            item.level,
                            item.item_report,
                            {   tbc: Number(item.type_report_id.tbc) === 3 && item.january.tbc === "" ? "0" : item.january.tbc, 
                                fcp: Number(item.type_report_id.fcp) === 3 && item.january.fcp === "" ? "0" : item.january.fcp, 
                                tbf: Number(item.type_report_id.tbf) === 3 && item.january.tbf === "" ? "0" : item.january.tbf
                            },
                            {   tbc: Number(item.type_report_id.tbc) === 3 && item.february.tbc === "" ? "0" : item.february.tbc, 
                                fcp: Number(item.type_report_id.fcp) === 3 && item.february.fcp === "" ? "0" : item.february.fcp,
                                tbf: Number(item.type_report_id.tbf) === 3 && item.february.tbf === "" ? "0" : item.february.tbf
                            },
                            {   tbc: Number(item.type_report_id.tbc) === 3 && item.march.tbc === "" ? "0" : item.march.tbc, 
                                fcp: Number(item.type_report_id.fcp) === 3 && item.march.fcp === "" ? "0" : item.march.fcp, 
                                tbf: Number(item.type_report_id.tbf) === 3 && item.march.tbf === "" ? "0" : item.march.tbf
                            },
                            {   tbc: Number(item.type_report_id.tbc) === 3 && item.april.tbc === "" ? "0" : item.april.tbc, 
                                fcp: Number(item.type_report_id.fcp) === 3 && item.april.fcp === "" ? "0" : item.april.fcp, 
                                tbf: Number(item.type_report_id.tbf) === 3 && item.april.tbf === "" ? "0" : item.april.tbf
                            },
                            {   tbc: Number(item.type_report_id.tbc) === 3 && item.may.tbc === "" ? "0" : item.may.tbc, 
                                fcp: Number(item.type_report_id.fcp) === 3 && item.may.fcp === "" ? "0" : item.may.fcp, 
                                tbf: Number(item.type_report_id.tbf) === 3 && item.may.tbf === "" ? "0" : item.may.tbf
                            },
                            {   tbc: Number(item.type_report_id.tbc) === 3 && item.june.tbc === "" ? "0" : item.june.tbc, 
                                fcp: Number(item.type_report_id.fcp) === 3 && item.june.fcp === "" ? "0" : item.june.fcp, 
                                tbf: Number(item.type_report_id.tbf) === 3 && item.june.tbf === "" ? "0" : item.june.tbf
                            },
                            {   tbc: Number(item.type_report_id.tbc) === 3 && item.july.tbc === "" ? "0" : item.july.tbc, 
                                fcp: Number(item.type_report_id.fcp) === 3 && item.july.fcp === "" ? "0" : item.july.fcp, 
                                tbf: Number(item.type_report_id.tbf) === 3 && item.july.tbf === "" ? "0" : item.july.tbf
                            },
                            {   tbc: Number(item.type_report_id.tbc) === 3 && item.august.tbc === "" ? "0" : item.august.tbc, 
                                fcp: Number(item.type_report_id.fcp) === 3 && item.august.fcp === "" ? "0" : item.august.fcp, 
                                tbf: Number(item.type_report_id.tbf) === 3 && item.august.tbf === "" ? "0" : item.august.tbf
                            },
                            {   tbc: Number(item.type_report_id.tbc) === 3 && item.september.tbc === "" ? "0" : item.september.tbc, 
                                fcp: Number(item.type_report_id.fcp) === 3 && item.september.fcp === "" ? "0" : item.september.fcp, 
                                tbf: Number(item.type_report_id.tbf) === 3 && item.september.tbf === "" ? "0" : item.september.tbf
                            },
                            {   tbc: Number(item.type_report_id.tbc) === 3 && item.october.tbc === "" ? "0" : item.october.tbc, 
                                fcp: Number(item.type_report_id.fcp) === 3 && item.october.fcp === "" ? "0" : item.october.fcp, 
                                tbf: Number(item.type_report_id.tbf) === 3 && item.october.tbf === "" ? "0" : item.october.tbf
                            },
                            {   tbc: Number(item.type_report_id.tbc) === 3 && item.november.tbc === "" ? "0" : item.november.tbc, 
                                fcp: Number(item.type_report_id.fcp) === 3 && item.november.fcp === "" ? "0" : item.november.fcp, 
                                tbf: Number(item.type_report_id.tbf) === 3 && item.november.tbf === "" ? "0" : item.november.tbf
                            },
                            {   tbc: Number(item.type_report_id.tbc) === 3 && item.december.tbc === "" ? "0" : item.december.tbc, 
                                fcp: Number(item.type_report_id.fcp) === 3 && item.december.fcp === "" ? "0" : item.december.fcp, 
                                tbf: Number(item.type_report_id.tbf) === 3 && item.december.tbf === "" ? "0" : item.december.tbf
                            },
                            item.total_current_year,
                            {   tbc: Number(item.type_report_id.tbc) === 3 && item.total_next_year.tbc === "" ? "0" : item.total_next_year.tbc, 
                                fcp: Number(item.type_report_id.fcp) === 3 && item.total_next_year.fcp === "" ? "0" : item.total_next_year.fcp, 
                                tbf: Number(item.type_report_id.tbf) === 3 && item.total_next_year.tbf === "" ? "0" : item.total_next_year.tbf
                            },
                            {   tbc: Number(item.type_report_id.tbc) === 3 && item.total_more_year.tbc === "" ? "0" : item.total_more_year.tbc, 
                                fcp: Number(item.type_report_id.fcp) === 3 && item.total_more_year.fcp === "" ? "0" : item.total_more_year.fcp, 
                                tbf: Number(item.type_report_id.tbf) === 3 && item.total_more_year.tbf === "" ? "0" : item.total_more_year.tbf 
                            },
                            item.orders,
                            item.error
                        ]
                    })
                    this.setState({ dataTable, dataLoaded: true, loading: false, buttonError: false, editable: true }, () => {
                        this.state.dataTable.map(item => {
                            if (item[25].length > 0) {
                                console.log('masuk')
                                this.setState({ buttonError: true, errorPreview: true, editable: true })
                            }
                        })
                        console.log(this.state.dataTable);
                    })
                }
            }
        })
    }

    uploadTP(type) {
        let data = []
        this.state.dataTable.map(i => {
            data.push({
                item_report_id: i[4],
                january: {
                    tbc: String(Number(i[9].tbc).toFixed(1)),
                    fcp: String(Number(i[9].fcp).toFixed(1)),
                    tbf: String(Number(i[9].tbf).toFixed(1))
                },
                february: {
                    tbc: String(Number(i[10].tbc).toFixed(1)),
                    fcp: String(Number(i[10].fcp).toFixed(1)),
                    tbf: String(Number(i[10].tbf).toFixed(1))
                },
                march: {
                    tbc: String(Number(i[11].tbc).toFixed(1)),
                    fcp: String(Number(i[11].fcp).toFixed(1)),
                    tbf: String(Number(i[11].tbf).toFixed(1))
                },
                april: {
                    tbc: String(Number(i[12].tbc).toFixed(1)),
                    fcp: String(Number(i[12].fcp).toFixed(1)),
                    tbf: String(Number(i[12].tbf).toFixed(1))
                },
                may: {
                    tbc: String(Number(i[13].tbc).toFixed(1)),
                    fcp: String(Number(i[13].fcp).toFixed(1)),
                    tbf: String(Number(i[13].tbf).toFixed(1))
                },
                june: {
                    tbc: String(Number(i[14].tbc).toFixed(1)),
                    fcp: String(Number(i[14].fcp).toFixed(1)),
                    tbf: String(Number(i[14].tbf).toFixed(1))
                },
                july: {
                    tbc: String(Number(i[15].tbc).toFixed(1)),
                    fcp: String(Number(i[15].fcp).toFixed(1)),
                    tbf: String(Number(i[15].tbf).toFixed(1))
                },
                august: {
                    tbc: String(Number(i[16].tbc).toFixed(1)),
                    fcp: String(Number(i[16].fcp).toFixed(1)),
                    tbf: String(Number(i[16].tbf).toFixed(1))
                },
                september: {
                    tbc: String(Number(i[17].tbc).toFixed(1)),
                    fcp: String(Number(i[17].fcp).toFixed(1)),
                    tbf: String(Number(i[17].tbf).toFixed(1))
                },
                october: {
                    tbc: String(Number(i[18].tbc).toFixed(1)),
                    fcp: String(Number(i[18].fcp).toFixed(1)),
                    tbf: String(Number(i[18].tbf).toFixed(1))
                },
                november: {
                    tbc: String(Number(i[19].tbc).toFixed(1)),
                    fcp: String(Number(i[19].fcp).toFixed(1)),
                    tbf: String(Number(i[19].tbf).toFixed(1))
                },
                december: {
                    tbc: String(Number(i[20].tbc).toFixed(1)),
                    fcp: String(Number(i[20].fcp).toFixed(1)),
                    tbf: String(Number(i[20].tbf).toFixed(1))
                },
                total_current_year: String(Number(i[21]).toFixed(1)),
                total_next_year: {
                    tbc: String(Number(i[22].tbc).toFixed(1)),
                    fcp: String(Number(i[22].fcp).toFixed(1)),
                    tbf: String(Number(i[22].tbf).toFixed(1))
                },
                total_more_year: {
                    tbc: String(Number(i[23].tbc).toFixed(1)),
                    fcp: String(Number(i[23].fcp).toFixed(1)),
                    tbf: String(Number(i[23].tbf).toFixed(1))
                }
            })
        })
        let body = {
            submission_id: this.props.submissionID,
            company_id: this.props.company.company_id,
            periode: this.props.periode,
            report_id: this.props.report_id,
            tax_planning: data,
            status: type
        }
        // console.log(data);
        api.create('UPLOAD').uploadMasterBudget(body).then(response => {
            console.log(response);
            if (response.data) {
                if (response.data.status === "success") {
                    this.props.onClickClose()
                    this.props.getReport()
                } else {
                    alert(response.data.status)
                }
            } else {
                this.setState({ loading: false })
                alert(response.problem)
            }
        })
    }

    handleValidate() {
        let data = []
        console.log(this.state.dataTable)
        this.state.dataTable.map(i => {
        console.log(i[0])
            data.push({
                item_report_id: i[4],
                january: {
                    tbc: i[1] === 3 && i[9].tbc === "" ? "0" : String(i[9].tbc),
                    fcp: i[2] === 3 && i[9].fcp === "" ? "0" : String(i[9].fcp),
                    tbf: i[3] === 3 && i[9].tbf === "" ? "0" : String(i[9].tbf)
                },
                february: {
                    tbc: i[1] === 3 && i[10].tbc === "" ? "0" : String(i[10].tbc),
                    fcp: i[2] === 3 && i[10].fcp === "" ? "0" : String(i[10].fcp),
                    tbf: i[3] === 3 && i[10].tbf === "" ? "0" : String(i[10].tbf)
                },
                march: {
                    tbc: i[1] === 3 && i[11].tbc === "" ? "0" : String(i[11].tbc),
                    fcp: i[2] === 3 && i[11].fcp === "" ? "0" : String(i[11].fcp),
                    tbf: i[3] === 3 && i[11].tbf === "" ? "0" : String(i[11].tbf)
                },
                april: {
                    tbc: i[1] === 3 && i[12].tbc === "" ? "0" : String(i[12].tbc),
                    fcp: i[2] === 3 && i[12].fcp === "" ? "0" : String(i[12].fcp),
                    tbf: i[3] === 3 && i[12].tbf === "" ? "0" : String(i[12].tbf)
                },
                may: {
                    tbc: i[1] === 3 && i[13].tbc === "" ? "0" : String(i[13].tbc),
                    fcp: i[2] === 3 && i[13].fcp === "" ? "0" : String(i[13].fcp),
                    tbf: i[3] === 3 && i[13].tbf === "" ? "0" : String(i[13].tbf)
                },
                june: {
                    tbc: i[1] === 3 && i[14].tbc === "" ? "0" : String(i[14].tbc),
                    fcp: i[2] === 3 && i[14].fcp === "" ? "0" : String(i[14].fcp),
                    tbf: i[3] === 3 && i[14].tbc === "" ? "0" : String(i[14].tbf)
                },
                july: {
                    tbc: i[1] === 3 && i[15].tbc === "" ? "0" : String(i[15].tbc),
                    fcp: i[2] === 3 && i[15].fcp === "" ? "0" : String(i[15].fcp),
                    tbf: i[3] === 3 && i[15].tbf === "" ? "0" : String(i[15].tbf)
                },
                august: {
                    tbc: i[1] === 3 && i[16].tbc === "" ? "0" : String(i[16].tbc),
                    fcp: i[2] === 3 && i[16].fcp === "" ? "0" : String(i[16].fcp),
                    tbf: i[3] === 3 && i[16].tbf === "" ? "0" : String(i[16].tbf)
                },
                september: {
                    tbc: i[1] === 3 && i[17].tbc === "" ? "0" : String(i[17].tbc),
                    fcp: i[2] === 3 && i[17].fcp === "" ? "0" : String(i[17].fcp),
                    tbf: i[3] === 3 && i[17].tbf === "" ? "0" : String(i[17].tbf)
                },
                october: {
                    tbc: i[1] === 3 && i[18].tbc === "" ? "0" : String(i[18].tbc),
                    fcp: i[2] === 3 && i[18].fcp === "" ? "0" : String(i[18].fcp),
                    tbf: i[3] === 3 && i[18].tbf === "" ? "0" : String(i[18].tbf)
                },
                november: {
                    tbc: i[1] === 3 && i[19].tbc === "" ? "0" : String(i[19].tbc),
                    fcp: i[2] === 3 && i[19].fcp === "" ? "0" : String(i[19].fcp),
                    tbf: i[3] === 3 && i[19].tbf === "" ? "0" : String(i[19].tbf)
                },
                december: {
                    tbc: i[1] === 3 && i[20].tbc === "" ? "0" : String(i[20].tbc),
                    fcp: i[2] === 3 && i[20].fcp === "" ? "0" : String(i[20].fcp),
                    tbf: i[3] === 3 && i[20].tbf === "" ? "0" : String(i[20].tbf)
                },
                total_current_year: i[2] === 3 && i[21] === "" ? "0" : String(i[21]),
                total_next_year: {
                    tbc: i[1] === 3 && i[22].tbc === "" ? "0" : String(i[22].tbc),
                    fcp: i[2] === 3 && i[22].fcp === "" ? "0" : String(i[22].fcp),
                    tbf: i[3] === 3 && i[22].tbf === "" ? "0" : String(i[22].tbf)
                },
                total_more_year: {
                    tbc: i[1] === 3 && i[23].tbc === "" ? "0" : String(i[23].tbc),
                    fcp: i[2] === 3 && i[23].fcp === "" ? "0" : String(i[23].fcp),
                    tbf: i[3] === 3 && i[23].tbf === "" ? "0" : String(i[23].tbf)
                }
            })
        })
        console.log(JSON.stringify(data))
        let payload = {
            "submission_id": this.props.submissionID,
            "company_id": this.props.company.company_id,
            "periode": this.props.periode,
            "report_id": this.props.report_id,
            "tax_planning": data,
            "status": "submitted"
        }
        api.create().validateSubmitReport(payload).then((response) => {
            console.log(response)
            if (response.data.data.result) {
                this.setState({ loading: false, buttonError: false, editable: false })
                // alert("Type Input Can't be Empty")
            } else {
                this.setState({ loading: false, buttonError: true, editable: true })
            }
        })
    }

    downloadTemplate = async () => {
        let res = await fetch(
            `https://tia.eksad.com/tia-reporting-dev/public/transaction/master_budget/download_template?report_id=${this.props.report_id}&&company_id=${this.props.company.company_id}&&year=${this.props.periode}`
        )
        res = await res.blob()
        console.log(res)
        if (res.size > 0) {
            let url = window.URL.createObjectURL(res);
            let a = document.createElement('a');
            a.href = url;
            a.download = 'Template Master Budget Tax Planning.xlsx';
            a.click();
        }
    }

    async downloadAllData() {
        let url = `https://tia.eksad.com/tia-reporting-dev/public/transaction/master_budget/export_master_budget?submission_id=${this.props.submissionID}&&report_id=${this.props.report_id}&&company_id=${this.props.company.company_id}&&year=${this.props.periode}&&revision=${this.props.revision}`
        console.log(url);
        let res = await fetch(
            `https://tia.eksad.com/tia-reporting-dev/public/transaction/master_budget/export_master_budget?submission_id=${this.props.submissionID}&&report_id=${this.props.report_id}&&company_id=${this.props.company.company_id}&&year=${this.props.periode}&&revision=${this.props.revision}`
        )
        res = await res.blob()
        this.setState({ loading: false })
        if (res.size > 0) {
            let url = window.URL.createObjectURL(res);
            let a = document.createElement('a');
            a.href = url;
            a.download = 'Master Budget Tax Planning.xlsx';
            a.click();
        }
    }

    closeAlert() {
        this.setState({ alert: false })
    }

    render() {
        let dataTable2 = this.state.dataTable
        const handleChange = (value, tableMeta, indexChilds) => {
            let val = String(value).split(",").join("")
            // let data = this.state.dataTable2
            let indexParent = dataTable2.findIndex((val) => val[4] === dataTable2[tableMeta.rowIndex][5])
            // ini buat input untuk perhitungan parent nya
            if (indexParent > 0) {
                if (indexChilds == 1) {
                    let a = dataTable2[tableMeta.rowIndex][tableMeta.columnIndex].fcp = Number(val)
                    let jagain = dataTable2[indexParent][tableMeta.columnIndex].fcp
                    a = dataTable2[indexParent][tableMeta.columnIndex].fcp = jagain === undefined ? (0 + Number(val)) : (Number(jagain) + Number(val))
                }
            } else {
                console.log(tableMeta)
                if (indexChilds == 0){
                    dataTable2[tableMeta.rowIndex][tableMeta.columnIndex].tbc = Number(val)
                }
                else if (indexChilds == 1){
                    dataTable2[tableMeta.rowIndex][tableMeta.columnIndex].fcp = Number(val)
                }
                else if (indexChilds == 2){
                    dataTable2[tableMeta.rowIndex][tableMeta.columnIndex].tbf = Number(val)
                }
            }
        }
        const handleTotal = (tableMeta) => {
            let total = 0
            dataTable2[tableMeta.rowIndex].map((item, index) => {
                if (index >= 9 && index <= 20) {
                    // console.log(item);
                    let valItem = item.fcp == undefined || item.fcp == "" ? 0 : item.fcp
                    total += Number(valItem)
                }
            })
            dataTable2[tableMeta.rowIndex][21] = total
            return total
        }
        const handleValue = (data) => {
            let total = 0
            // console.log(dataTable2)
            dataTable2.map((item, index) => {
                if (data.rowData[4] === item[5]) {
                    total = item[data.columnIndex] === undefined ? (Number(total) + 0) : (Number(total) + Number(item[data.columnIndex].fcp))
                }
            })
            let indexParent = dataTable2.findIndex((val) => val[4] === dataTable2[data.rowIndex][5])
            let a = dataTable2[data.rowIndex][data.columnIndex].fcp = Number(total)
            // console.log(indexParent);
            return a
        }

        const handleFormula = (data, tableMeta, month, rowColumn) => {
            let rilFormula = String(rowColumn == 0 ? tableMeta.rowData[6].tbc : tableMeta.rowData[6].tbf)
            if (rilFormula.includes('#')) {
                if (this.props.status === "not-yet") {
                    let splitOrder = String(rowColumn == 0 ? tableMeta.rowData[6].tbc : tableMeta.rowData[6].tbf).split('@')
                    for (let index = 0; index < splitOrder.length; index++) {
                        if (splitOrder[index] === "") {
                        } else {
                            if (splitOrder[index].includes('#')) {

                            } else {
                                let splitOperator = splitOrder[index].match(/[a-zA-Z]+|[0-9]+|[-!$%^&*()_+|~=`{}\[\]:";'<>?,.\/]+(?:\.[0-9]+@|)/g)
                                let reg = /^\d+$/
                                splitOperator.map((item) => {
                                    if (reg.test(item) === true) {
                                        let i = dataTable2.findIndex((val) => val[24] == item)
                                        if (i > 0) {
                                            rilFormula = rilFormula.replace(item, dataTable2[i][tableMeta.columnIndex] === "" ? "0" : dataTable2[i][tableMeta.columnIndex])
                                        }
                                    }
                                })
                            }
                        }
                    }
                    let body = {
                        "submission_id": null,
                        "company_id": this.props.company.company_id,
                        "report_id": this.props.report_id,
                        "year": this.props.periode,
                        "month": month,
                        "formula": rilFormula
                    }
                    api.create().countingFormula(body).then(response => {
                        // console.log(response);
                    })
                } else {
                    let body = {
                        "submission_id": this.props.submissionID,
                        "company_id": this.props.company.company_id,
                        "report_id": this.props.report_id,
                        "year": this.props.periode,
                        "month": month,
                        "formula": rilFormula
                    }
                    api.create().countingFormula(body).then(response => {
                        // console.log(response)
                        // console.log(tableMeta)
                        // console.log(tableMeta.rowIndex)
                        // console.log(rowColumn)
                        if (response.data) {
                            if (response.data.status === "success") {
                                return response.data.data.result
                            }
                        }
                    })
                }
            } else {
                let kondisi = rowColumn == 0 ? tableMeta.rowData[6].tbc : tableMeta.rowData[6].tbf
                let arrayFormula = kondisi.match(/[a-zA-Z]+|[0-9]+|[-!$%^&*()_+|~=`{}\[\]:";'<>?,.\/]+(?:\.[0-9]+@|)/g)
                let arrayJumlah = []
                arrayFormula.map((item, indexs) => {
                    let index = dataTable2.findIndex((val) => val[24] == item)
                    if (index > 0) {
                        arrayJumlah.push(dataTable2[index][tableMeta.columnIndex])
                    } else {
                        arrayJumlah.push(item)
                    }
                    // if (indexs % 2 !== 0) {
                    //     operator.push(item)
                    // }
                })
                let array = arrayJumlah
                let total = 0
                let opt = ""
                array.map((item, index) => {
                    if (item == "+") {
                        opt = "tambah"
                    } else if (item == "-") {
                        opt = "kurang"
                    } else if (item == "*") {
                        opt = "kali"
                    } else if (item == "/") {
                        opt = "bagi"
                    } else {
                        if (opt == "tambah") {
                            total = Number(total) + Number(item)
                        } else if (opt == "kurang") {
                            total = Number(total) - Number(item)
                        } else if (opt == "kali") {
                            total = Number(total) * Number(item)
                        } else if (opt == "bagi") {
                            total = Number(total) / Number(item)
                        } else {
                            total += item
                        }
                    }
                })
                if (R.equals(Number(total), NaN) ){
                    total = {tbc: "", fcp: "", tbf: ""}
                } else {
                    total = Number(total)
                }
                // console.log(Number(total))
                // console.log(dataTable2[tableMeta.rowIndex])
                let a = dataTable2[tableMeta.rowIndex][tableMeta.columnIndex] = total
                return a
            }

        }
        const columns = [{
            name: "",
            options: {
                display: false
            }
        }, {
            name: "",
            options: {
                display: false
            }
        }, {
            name: "",
            options: {
                display: false
            }
        }, {
            name: "",
            options: {
                display: false
            }
        }, {
            name: "",
            options: {
                display: false
            }
        }, {
            name: "",
            options: {
                display: false
            }
        }, {
            name: "",
            options: {
                display: false
            }
        }, {
            name: "",
            options: {
                display: false
            }
        }, {
            name: this.state.judulColumn !== null ? this.state.judulColumn[1] : "Account",
            options: {
                customHeadRender: (columnMeta) => (
                    <TableCell key={columnMeta.index} style={{ ...style, top: 0, zIndex: 102, backgroundColor: '#1c71b8', width: 300 }}>
                        <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'left' }}>{columnMeta.name}</Typography>
                    </TableCell>
                ),
                setCellProps: () => ({ style }),
                customBodyRender: (val, tableMeta) => {
                    return (
                        <div style={{ width: 300 }}>
                            {tableMeta.rowData[24] ?
                                tableMeta.rowData[24].length > 0 ?
                                    <div style={{ paddingLeft: 20 * Number(tableMeta.rowData[4]) }}>
                                        <LightTooltip title={"Report Items Not Registered"} arrow>
                                            <span style={{ fontSize: 12, color: 'red' }}>{tableMeta.rowData[0] === 4 ? "" : val}</span>
                                        </LightTooltip>
                                    </div>
                                    :
                                    tableMeta.rowData[7] == 0 ?
                                        <span style={{ fontSize: 12, fontWeight: 'bold' }}>{String(tableMeta.rowData[0] === 4 ? "" : val).toUpperCase()}</span>
                                        :
                                        <div style={{ paddingLeft: 20 * Number(tableMeta.rowData[7]) }}>
                                            <span style={{ fontSize: 12 }}>{tableMeta.rowData[0] === 4 ? "" : val}</span>
                                        </div>
                                :
                                tableMeta.rowData[7] == 0 ?
                                    <span style={{ fontSize: 12, fontWeight: 'bold' }}>{String(tableMeta.rowData[0] === 4 ? "" : val).toUpperCase()}</span>
                                    :
                                    <div style={{ paddingLeft: 20 * Number(tableMeta.rowData[7]) }}>
                                        <span style={{ fontSize: 12 }}>{tableMeta.rowData[0] === 4 ? "" : val}</span>
                                    </div>
                            }
                        </div>
                    )
                }
            }
        }, {
            name: this.state.judulColumn !== null ? this.state.judulColumn[2] : `Jan ${this.props.periode}`,
            options: {
                customHeadRender: (columnMeta) => (
                    <th  style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 13, fontWeight: 1, width: 150, borderRight: "1px solid rgb(255, 255, 255)" }} >
                        {/* <TableCell style={{ ...style2, top: 0, zIndex: 99, backgroundColor: '#1c71b8', width: 96 }}>
                            <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'center' }}>{columnMeta.name}</Typography>
                        </TableCell> */}
                        <div style={{ borderBottom: "1px #fff solid", textAlign: 'center', fontSize: 12, fontWeight: 'bold', padding: 5 }}>{columnMeta.name}</div>
                        <div className="grid grid-3x" style={{...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 12, fontWeight: 'bold', position: "sticky" }}>
                            <div className="column-1" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Commercial) MTD"}</span>
                            </div>
                            <div className="column-2" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Fiscal Correction Positive /(Negative)"}</span>
                            </div>
                            <div className="column-3" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Fiscal) MTD"}</span>
                            </div>
                        </div>
                    </th>
                ),
                setCellProps: () => ({ style2 }),
                customBodyRender: (value, tableMeta, updateValue) => {
                    // console.log(value)
                    return (
                        <div>
                            <div className="grid grid-3x content-center">
                                <div className="col-1">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[1] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbc}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            decimalSeparator={"."}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbc).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 0)
                                                                console.log(dataTable2)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[1] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[1] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[1] === 6 ?
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleFormula(value, tableMeta, 1, 0)).toFixed(1)}
                                                    />
                                                        :
                                                        tableMeta.rowData[1] === 5 ?
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder=""
                                                            disabled={false}
                                                            value={Number(handleFormula(value, tableMeta, 1, 0)).toFixed(1)}
                                                        />
                                                            :
                                                            tableMeta.rowData[1] === 1 ?
                                                                // value[0] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[0])}
                                                                //     />
                                                                null
                                                                :
                                                                // <span>validasi</span>
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-2">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[2] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.fcp}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.fcp).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 1)
                                                                console.log(dataTable2)
                                                                // console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[2] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[2] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[2] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[2] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[2] === 1 ?
                                                                // value[1] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value.fcp)}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-3">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[3] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbf}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbf).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 2)
                                                                console.log(dataTable2)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[3] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[3] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[3] === 6 ?
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleFormula(value, tableMeta, 1, 2)).toFixed(1)}
                                                    />
                                                        :
                                                        tableMeta.rowData[3] === 5 ?
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder=""
                                                            disabled={false}
                                                            value={Number(handleFormula(value, tableMeta, 1, 2)).toFixed(1)}
                                                        />
                                                            :
                                                            tableMeta.rowData[3] === 1 ?
                                                                // value[2] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[2])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                            </div>
                        </div>
                    )
                }
            }
        }, {
            name: this.state.judulColumn !== null ? this.state.judulColumn[5] : `Feb ${this.props.periode}`,
            options: {
                customHeadRender: (columnMeta) => (                    
                <th  style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 13, fontWeight: 1, width: 150, borderRight: "1px solid rgb(255, 255, 255)" }} >
                        {/* <TableCell style={{ ...style2, top: 0, zIndex: 99, backgroundColor: '#1c71b8', width: 96 }}>
                            <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'center' }}>{columnMeta.name}</Typography>
                        </TableCell> */}
                        <div style={{ borderBottom: "1px #fff solid", textAlign: 'center', fontSize: 12, fontWeight: 'bold', padding: 5 }}>{columnMeta.name}</div>
                        <div className="grid grid-3x" style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 12, fontWeight: 'bold', position: "sticky" }}>
                            <div className="column-1" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Commercial) MTD"}</span>
                            </div>
                            <div className="column-2" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Fiscal Correction Positive /(Negative)"}</span>
                            </div>
                            <div className="column-3" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Fiscal) MTD"}</span>
                            </div>
                        </div>
                    </th>
                ),
                setCellProps: () => ({ style2 }),
                customBodyRender: (value, tableMeta, updateValue) => {
                    // console.log(value)
                    return (
                        <div>
                            <div className="grid grid-3x content-center">
                                <div className="col-1">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[1] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbc}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbc).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 0)
                                                                console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[1] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[1] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[1] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[1] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[1] === 1 ?
                                                                // value[0] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[0])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-2">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[2] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.fcp}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.fcp).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 1)
                                                                console.log(dataTable2)
                                                                // console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[2] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[2] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[2] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[2] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[2] === 1 ?
                                                                // value[1] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value.fcp)}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-3">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[3] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbf}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbf).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 2)
                                                                console.log(dataTable2)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[3] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[3] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[3] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[3] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[3] === 1 ?
                                                                // value[2] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[2])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                            </div>
                        </div>
                    )
                }
            }
        }, 
        {
            name: this.state.judulColumn !== null ? this.state.judulColumn[8] : `Mar ${this.props.periode}`,
            options: {
                customHeadRender: (columnMeta) => (
                    <th  style={{ ...style2,  backgroundColor: '#1c71b8', color: '#fff', fontSize: 13, fontWeight: 1, width: 150, borderRight: "1px solid rgb(255, 255, 255)" }} >
                        {/* <TableCell style={{ ...style2, top: 0, zIndex: 99, backgroundColor: '#1c71b8', width: 96 }}>
                            <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'center' }}>{columnMeta.name}</Typography>
                        </TableCell> */}
                        <div style={{ borderBottom: "1px #fff solid", textAlign: 'center', fontSize: 12, fontWeight: 'bold', padding: 5 }}>{columnMeta.name}</div>
                        <div className="grid grid-3x" style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 12, fontWeight: 'bold', position: "sticky" }}>
                            <div className="column-1" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Commercial) MTD"}</span>
                            </div>
                            <div className="column-2" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Fiscal Correction Positive /(Negative)"}</span>
                            </div>
                            <div className="column-3" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Fiscal) MTD"}</span>
                            </div>
                        </div>
                    </th>
                ),
                setCellProps: () => ({ style2 }),
                customBodyRender: (value, tableMeta, updateValue) => {
                    // console.log(value)
                    return (
                        <div>
                            <div className="grid grid-3x content-center">
                                <div className="col-1">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[1] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbc}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbc)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 0)
                                                                console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[1] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[1] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[1] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[1] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[1] === 1 ?
                                                                // value[0] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[0])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-2">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[2] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.fcp}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.fcp).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 1)
                                                                console.log(dataTable2)
                                                                // console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[2] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[2] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[2] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[2] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[2] === 1 ?
                                                                // value[1] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value.fcp)}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-3">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[3] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbf}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbf).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 2)
                                                                console.log(dataTable2)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[3] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[3] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[3] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[3] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[3] === 1 ?
                                                                // value[2] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[2])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                            </div>
                        </div>
                    )
                }
            }
        },{
            name: this.state.judulColumn !== null ? this.state.judulColumn[11] : `Apr ${this.props.periode}`,
            options: {
                customHeadRender: (columnMeta) => (
                    <th  style={{ ...style2,  backgroundColor: '#1c71b8', color: '#fff', fontSize: 13, fontWeight: 1, width: 150, borderRight: "1px solid rgb(255, 255, 255)" }} >
                        {/* <TableCell style={{ ...style2, top: 0, zIndex: 99, backgroundColor: '#1c71b8', width: 96 }}>
                            <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'center' }}>{columnMeta.name}</Typography>
                        </TableCell> */}
                        <div style={{ borderBottom: "1px #fff solid", textAlign: 'center', fontSize: 12, fontWeight: 'bold', padding: 5 }}>{columnMeta.name}</div>
                        <div className="grid grid-3x" style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 12, fontWeight: 'bold', position: "sticky" }}>
                            <div className="column-1" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Commercial) MTD"}</span>
                            </div>
                            <div className="column-2" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Fiscal Correction Positive /(Negative)"}</span>
                            </div>
                            <div className="column-3" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Fiscal) MTD"}</span>
                            </div>
                        </div>
                    </th>
                ),
                setCellProps: () => ({ style2 }),
                customBodyRender: (value, tableMeta, updateValue) => {
                    // console.log(value)
                    return (
                        <div>
                            <div className="grid grid-3x content-center">
                                <div className="col-1">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[1] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbc}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbc).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 0)
                                                                console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[1] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[1] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[1] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[1] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[1] === 1 ?
                                                                // value[0] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[0])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-2">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[2] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.fcp}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.fcp).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 1)
                                                                console.log(dataTable2)
                                                                // console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[2] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[2] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[2] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[2] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[2] === 1 ?
                                                                // value[1] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value.fcp)}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-3">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[3] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbf}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbf).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 2)
                                                                console.log(dataTable2)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[3] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[3] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[3] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[3] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[3] === 1 ?
                                                                // value[2] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[2])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                            </div>
                        </div>
                    )
                }
            }
        },{
            name: this.state.judulColumn !== null ? this.state.judulColumn[14] : `May ${this.props.periode}`,
            options: {
                customHeadRender: (columnMeta) => (
                    <th  style={{ ...style2,  backgroundColor: '#1c71b8', color: '#fff', fontSize: 13, fontWeight: 1, width: 150, borderRight: "1px solid rgb(255, 255, 255)" }} >
                        {/* <TableCell style={{ ...style2, top: 0, zIndex: 99, backgroundColor: '#1c71b8', width: 96 }}>
                            <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'center' }}>{columnMeta.name}</Typography>
                        </TableCell> */}
                        <div style={{ borderBottom: "1px #fff solid", textAlign: 'center', fontSize: 12, fontWeight: 'bold', padding: 5 }}>{columnMeta.name}</div>
                        <div className="grid grid-3x" style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 12, fontWeight: 'bold', position: "sticky" }}>
                            <div className="column-1" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Commercial) MTD"}</span>
                            </div>
                            <div className="column-2" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Fiscal Correction Positive /(Negative)"}</span>
                            </div>
                            <div className="column-3" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Fiscal) MTD"}</span>
                            </div>
                        </div>
                    </th>
                ),
                setCellProps: () => ({ style2 }),
                customBodyRender: (value, tableMeta, updateValue) => {
                    // console.log(value)
                    return (
                        <div>
                            <div className="grid grid-3x content-center">
                                <div className="col-1">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[1] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbc}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbc).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 0)
                                                                console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[1] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[1] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[1] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[1] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[1] === 1 ?
                                                                // value[0] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[0])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-2">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[2] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.fcp}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.fcp).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 1)
                                                                console.log(dataTable2)
                                                                // console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[2] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[2] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[2] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[2] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[2] === 1 ?
                                                                // value[1] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value.fcp)}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-3">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[3] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbf}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbf).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 2)
                                                                console.log(dataTable2)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[3] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[3] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[3] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[3] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[3] === 1 ?
                                                                // value[2] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[2])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                            </div>
                        </div>
                    )
                }
            }
        },{
            name: this.state.judulColumn !== null ? this.state.judulColumn[17] : `Jun ${this.props.periode}`,
            options: {
                customHeadRender: (columnMeta) => (
                    <th  style={{ ...style2,  backgroundColor: '#1c71b8', color: '#fff', fontSize: 13, fontWeight: 1, width: 150, borderRight: "1px solid rgb(255, 255, 255)" }} >
                        {/* <TableCell style={{ ...style2, top: 0, zIndex: 99, backgroundColor: '#1c71b8', width: 96 }}>
                            <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'center' }}>{columnMeta.name}</Typography>
                        </TableCell> */}
                        <div style={{ borderBottom: "1px #fff solid", textAlign: 'center', fontSize: 12, fontWeight: 'bold', padding: 5 }}>{columnMeta.name}</div>
                        <div className="grid grid-3x" style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 12, fontWeight: 'bold', position: "sticky" }}>
                            <div className="column-1" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Commercial) MTD"}</span>
                            </div>
                            <div className="column-2" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Fiscal Correction Positive /(Negative)"}</span>
                            </div>
                            <div className="column-3" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Fiscal) MTD"}</span>
                            </div>
                        </div>
                    </th>
                ),
                setCellProps: () => ({ style2 }),
                customBodyRender: (value, tableMeta, updateValue) => {
                    // console.log(value)
                    return (
                        <div>
                            <div className="grid grid-3x content-center">
                                <div className="col-1">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[1] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbc}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbc).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 0)
                                                                console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[1] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[1] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[1] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[1] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[1] === 1 ?
                                                                // value[0] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[0])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-2">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[2] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.fcp}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.fcp).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 1)
                                                                console.log(dataTable2)
                                                                // console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[2] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[2] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[2] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[2] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[2] === 1 ?
                                                                // value[1] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value.fcp)}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-3">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[3] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbf}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbf).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 2)
                                                                console.log(dataTable2)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[3] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[3] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[3] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[3] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[3] === 1 ?
                                                                // value[2] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[2])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                            </div>
                        </div>
                    )
                }
            }
        },{
            name: this.state.judulColumn !== null ? this.state.judulColumn[20] : `Jul ${this.props.periode}`,
            options: {
                customHeadRender: (columnMeta) => (
                    <th  style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 13, fontWeight: 1, width: 150, borderRight: "1px solid rgb(255, 255, 255)" }} >
                        {/* <TableCell style={{ ...style2, top: 0, zIndex: 99, backgroundColor: '#1c71b8', width: 96 }}>
                            <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'center' }}>{columnMeta.name}</Typography>
                        </TableCell> */}
                        <div style={{ borderBottom: "1px #fff solid", textAlign: 'center', fontSize: 12, fontWeight: 'bold', padding: 5 }}>{columnMeta.name}</div>
                        <div className="grid grid-3x" style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 12, fontWeight: 'bold', position: "sticky" }}>
                            <div className="column-1" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Commercial) MTD"}</span>
                            </div>
                            <div className="column-2" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Fiscal Correction Positive /(Negative)"}</span>
                            </div>
                            <div className="column-3" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Fiscal) MTD"}</span>
                            </div>
                        </div>
                    </th>
                ),
                setCellProps: () => ({ style2 }),
                customBodyRender: (value, tableMeta, updateValue) => {
                    // console.log(value)
                    return (
                        <div>
                            <div className="grid grid-3x content-center">
                                <div className="col-1">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[1] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbc}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbc).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 0)
                                                                console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[1] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[1] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[1] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[1] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[1] === 1 ?
                                                                // value[0] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[0])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-2">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[2] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.fcp}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.fcp).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 1)
                                                                console.log(dataTable2)
                                                                // console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[2] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[2] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[2] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[2] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[2] === 1 ?
                                                                // value[1] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value.fcp)}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-3">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[3] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbf}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbf).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 2)
                                                                console.log(dataTable2)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[3] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[3] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[3] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[3] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[3] === 1 ?
                                                                // value[2] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[2])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                            </div>
                        </div>
                    )
                }
            }
        },{
            name: this.state.judulColumn !== null ? this.state.judulColumn[23] : `Aug ${this.props.periode}`,
            options: {
                customHeadRender: (columnMeta) => (
                    <th  style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 13, fontWeight: 1, width: 150, borderRight: "1px solid rgb(255, 255, 255)" }} >
                        {/* <TableCell style={{ ...style2, top: 0, zIndex: 99, backgroundColor: '#1c71b8', width: 96 }}>
                            <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'center' }}>{columnMeta.name}</Typography>
                        </TableCell> */}
                        <div style={{ borderBottom: "1px #fff solid", textAlign: 'center', fontSize: 12, fontWeight: 'bold', padding: 5 }}>{columnMeta.name}</div>
                        <div className="grid grid-3x" style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 12, fontWeight: 'bold', position: "sticky" }}>
                            <div className="column-1" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Commercial) MTD"}</span>
                            </div>
                            <div className="column-2" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Fiscal Correction Positive /(Negative)"}</span>
                            </div>
                            <div className="column-3" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Fiscal) MTD"}</span>
                            </div>
                        </div>
                    </th>
                ),
                setCellProps: () => ({ style2 }),
                customBodyRender: (value, tableMeta, updateValue) => {
                    // console.log(value)
                    return (
                        <div>
                            <div className="grid grid-3x content-center">
                                <div className="col-1">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[1] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbc}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbc).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 0)
                                                                console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[1] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[1] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[1] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[1] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[1] === 1 ?
                                                                // value[0] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[0])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-2">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[2] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.fcp}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.fcp).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 1)
                                                                console.log(dataTable2)
                                                                // console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[2] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[2] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[2] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[2] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[2] === 1 ?
                                                                // value[1] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value.fcp)}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-3">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[3] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbf}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbf).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 2)
                                                                console.log(dataTable2)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[3] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[3] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[3] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[3] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[3] === 1 ?
                                                                // value[2] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[2])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                            </div>
                        </div>
                    )
                }
            }
        },{
            name: this.state.judulColumn !== null ? this.state.judulColumn[26] : `Sep ${this.props.periode}`,
            options: {
                customHeadRender: (columnMeta) => (
                    <th  style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 13, fontWeight: 1, width: 150, borderRight: "1px solid rgb(255, 255, 255)" }} >
                        {/* <TableCell style={{ ...style2, top: 0, zIndex: 99, backgroundColor: '#1c71b8', width: 96 }}>
                            <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'center' }}>{columnMeta.name}</Typography>
                        </TableCell> */}
                        <div style={{ borderBottom: "1px #fff solid", textAlign: 'center', fontSize: 12, fontWeight: 'bold', padding: 5 }}>{columnMeta.name}</div>
                        <div className="grid grid-3x" style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 12, fontWeight: 'bold', position: "sticky" }}>
                            <div className="column-1" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Commercial) MTD"}</span>
                            </div>
                            <div className="column-2" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Fiscal Correction Positive /(Negative)"}</span>
                            </div>
                            <div className="column-3" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Fiscal) MTD"}</span>
                            </div>
                        </div>
                    </th>
                ),
                setCellProps: () => ({ style2 }),
                customBodyRender: (value, tableMeta, updateValue) => {
                    // console.log(value)
                    return (
                        <div>
                            <div className="grid grid-3x content-center">
                                <div className="col-1">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[1] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbc}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbc).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 0)
                                                                console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[1] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[1] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[1] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[1] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[1] === 1 ?
                                                                // value[0] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[0])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-2">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[2] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.fcp}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.fcp).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 1)
                                                                console.log(dataTable2)
                                                                // console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[2] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[2] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[2] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[2] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[2] === 1 ?
                                                                // value[1] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value.fcp)}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-3">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[3] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbf}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbf).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 2)
                                                                console.log(dataTable2)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[3] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[3] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[3] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[3] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[3] === 1 ?
                                                                // value[2] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[2])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                            </div>
                        </div>
                    )
                }
            }
        },{
            name: this.state.judulColumn !== null ? this.state.judulColumn[29] : `Oct ${this.props.periode}`,
            options: {
                customHeadRender: (columnMeta) => (
                    <th  style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 13, fontWeight: 1, width: 150, borderRight: "1px solid rgb(255, 255, 255)" }} >
                        {/* <TableCell style={{ ...style2, top: 0, zIndex: 99, backgroundColor: '#1c71b8', width: 96 }}>
                            <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'center' }}>{columnMeta.name}</Typography>
                        </TableCell> */}
                        <div style={{ borderBottom: "1px #fff solid", textAlign: 'center', fontSize: 12, fontWeight: 'bold', padding: 5 }}>{columnMeta.name}</div>
                        <div className="grid grid-3x" style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 12, fontWeight: 'bold', position: "sticky" }}>
                            <div className="column-1" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Commercial) MTD"}</span>
                            </div>
                            <div className="column-2" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Fiscal Correction Positive /(Negative)"}</span>
                            </div>
                            <div className="column-3" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Fiscal) MTD"}</span>
                            </div>
                        </div>
                    </th>
                ),
                setCellProps: () => ({ style2 }),
                customBodyRender: (value, tableMeta, updateValue) => {
                    // console.log(value)
                    return (
                        <div>
                            <div className="grid grid-3x content-center">
                                <div className="col-1">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[1] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbc}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbc).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 0)
                                                                console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[1] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[1] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[1] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[1] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[1] === 1 ?
                                                                // value[0] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[0])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-2">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[2] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.fcp}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.fcp).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 1)
                                                                console.log(dataTable2)
                                                                // console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[2] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[2] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[2] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[2] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[2] === 1 ?
                                                                // value[1] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value.fcp)}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-3">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[3] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbf}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbf).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 2)
                                                                console.log(dataTable2)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[3] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[3] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[3] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[3] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[3] === 1 ?
                                                                // value[2] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[2])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                            </div>
                        </div>
                    )
                }
            }
        },{
            name: this.state.judulColumn !== null ? this.state.judulColumn[32] : `Nov ${this.props.periode}`,
            options: {
                customHeadRender: (columnMeta) => (
                    <th  style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 13, fontWeight: 1, width: 150, borderRight: "1px solid rgb(255, 255, 255)" }} >
                        {/* <TableCell style={{ ...style2, top: 0, zIndex: 99, backgroundColor: '#1c71b8', width: 96 }}>
                            <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'center' }}>{columnMeta.name}</Typography>
                        </TableCell> */}
                        <div style={{ borderBottom: "1px #fff solid", textAlign: 'center', fontSize: 12, fontWeight: 'bold', padding: 5 }}>{columnMeta.name}</div>
                        <div className="grid grid-3x" style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 12, fontWeight: 'bold', position: "sticky" }}>
                            <div className="column-1" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Commercial) MTD"}</span>
                            </div>
                            <div className="column-2" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Fiscal Correction Positive /(Negative)"}</span>
                            </div>
                            <div className="column-3" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Fiscal) MTD"}</span>
                            </div>
                        </div>
                    </th>
                ),
                setCellProps: () => ({ style2 }),
                customBodyRender: (value, tableMeta, updateValue) => {
                    // console.log(value)
                    return (
                        <div>
                            <div className="grid grid-3x content-center">
                                <div className="col-1">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[1] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbc}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbc).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 0)
                                                                console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[1] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[1] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[1] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[1] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[1] === 1 ?
                                                                // value[0] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[0])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-2">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[2] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.fcp}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.fcp).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 1)
                                                                console.log(dataTable2)
                                                                // console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[2] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[2] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[2] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[2] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[2] === 1 ?
                                                                // value[1] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value.fcp)}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-3">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[3] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbf}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbf).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 2)
                                                                console.log(dataTable2)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[3] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[3] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[3] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[3] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[3] === 1 ?
                                                                // value[2] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[2])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                            </div>
                        </div>
                    )
                }
            }
        },{
            name: this.state.judulColumn !== null ? this.state.judulColumn[35] : `Dec ${this.props.periode}`,
            options: {
                customHeadRender: (columnMeta) => (
                    <th  style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 13, fontWeight: 1, width: 150, borderRight: "1px solid rgb(255, 255, 255)" }} >
                        {/* <TableCell style={{ ...style2, top: 0, zIndex: 99, backgroundColor: '#1c71b8', width: 96 }}>
                            <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'center' }}>{columnMeta.name}</Typography>
                        </TableCell> */}
                        <div style={{ borderBottom: "1px #fff solid", textAlign: 'center', fontSize: 12, fontWeight: 'bold', padding: 5 }}>{columnMeta.name}</div>
                        <div className="grid grid-3x" style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 12, fontWeight: 'bold', position: "sticky" }}>
                            <div className="column-1" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Commercial) MTD"}</span>
                            </div>
                            <div className="column-2" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Fiscal Correction Positive /(Negative)"}</span>
                            </div>
                            <div className="column-3" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Fiscal) MTD"}</span>
                            </div>
                        </div>
                    </th>
                ),
                setCellProps: () => ({ style2 }),
                customBodyRender: (value, tableMeta, updateValue) => {
                    // console.log(value)
                    return (
                        <div>
                            <div className="grid grid-3x content-center">
                                <div className="col-1">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[1] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbc}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbc).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 0)
                                                                console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[1] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[1] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[1] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[1] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[1] === 1 ?
                                                                // value[0] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[0])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-2">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[2] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.fcp}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.fcp).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 1)
                                                                console.log(dataTable2)
                                                                // console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[2] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[2] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[2] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[2] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[2] === 1 ?
                                                                // value[1] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value.fcp)}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-3">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[3] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbf}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbf).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 2)
                                                                console.log(dataTable2)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[3] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[3] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[3] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[3] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[3] === 1 ?
                                                                // value[2] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[2])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                            </div>
                        </div>
                    )
                }
            }
        },{
            name: this.state.judulColumn !== null ? this.state.judulColumn[38] : `${this.props.periode}`,
            options: {
                customHeadRender: (columnMeta) => (
                    <div  style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 13, fontWeight: 1, width: 150, borderRight: "1px solid rgb(255, 255, 255)" }} >
                        {/* <TableCell style={{ ...style2, top: 0, zIndex: 99, backgroundColor: '#1c71b8', width: 96 }}>
                            <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'center' }}>{columnMeta.name}</Typography>
                        </TableCell> */}
                        <div style={{ borderBottom: "1px #fff solid", textAlign: 'center', fontSize: 12, fontWeight: 'bold', padding: 5, paddingTop: 8 }}>{columnMeta.name}</div>
                        <div style={{ ...style2, backgroundColor: '#1c71b8', color: '#fff', fontSize: 12, fontWeight: 'bold', position: "sticky", paddingBottom: 20 }}>
                            <div style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Fiscal)"}</span>
                            </div>
                        </div>
                    </div>
                ),
                setCellProps: () => ({ style2 }),
                customBodyRender: (value, tableMeta, updateValue) => {
                    return (
                        <div>
                            <div className="grid grid-3x content-center">
                                {/* <div className="col-1"> */}
                                    <div style={{ textAlign: 'right' }}>
                                    {tableMeta.rowData[2] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value}
                                                    control={
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     value={value.tbc}
                                                        //     onBlur={(event) => {
                                                        //         // updateValue(event.target.value)
                                                        //         // handleChange(event.target.value, tableMeta)
                                                        //         console.log(event.target.value)
                                                        //     }}
                                                        // />
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(handleTotal(tableMeta)).toFixed(1)}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[1] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[1] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[1] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[1] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[1] === 1 ?
                                                                // value[0] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[0])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                {/* </div> */}
                            </div>
                        </div>
                    )
                }
            }
        },{
            name: this.state.judulColumn !== null ? this.state.judulColumn[39] : `${Number(this.props.periode) + 1}`,
            options: {
                customHeadRender: (columnMeta) => (
                    <th  style={{ ...style2, backgroundColor: '#37b5e6', color: '#fff', fontSize: 13, fontWeight: 1, width: 150, borderRight: "1px solid rgb(255, 255, 255)" }} >
                        {/* <TableCell style={{ ...style2, top: 0, zIndex: 99, backgroundColor: '#1c71b8', width: 96 }}>
                            <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'center' }}>{columnMeta.name}</Typography>
                        </TableCell> */}
                        <div style={{ borderBottom: "1px #fff solid", textAlign: 'center', fontSize: 12, fontWeight: 'bold', padding: 5 }}>{columnMeta.name}</div>
                        <div className="grid grid-3x" style={{ ...style2, backgroundColor: '#37b5e6', color: '#fff', fontSize: 12, fontWeight: 'bold', position: "sticky" }}>
                            <div className="column-1" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Commercial) MTD"}</span>
                            </div>
                            <div className="column-2" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Fiscal Correction Positive /(Negative)"}</span>
                            </div>
                            <div className="column-3" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Fiscal) MTD"}</span>
                            </div>
                        </div>
                    </th>
                ),
                setCellProps: () => ({ style2 }),
                customBodyRender: (value, tableMeta, updateValue) => {
                    // console.log(value)
                    return (
                        <div>
                            <div className="grid grid-3x content-center">
                                <div className="col-1">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[1] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbc}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbc).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 0)
                                                                console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[1] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[1] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[1] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[1] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[1] === 1 ?
                                                                // value[0] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[0])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-2">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[2] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.fcp}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.fcp).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 1)
                                                                console.log(dataTable2)
                                                                // console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[2] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[2] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[2] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[2] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[2] === 1 ?
                                                                // value[1] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value.fcp)}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-3">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[3] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbf}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbf).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 2)
                                                                console.log(dataTable2)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[3] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[3] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[3] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[3] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[3] === 1 ?
                                                                // value[2] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[2])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                            </div>
                        </div>
                    )
                }
            }
        },{
            name: this.state.judulColumn !== null ? this.state.judulColumn[42] : `${Number(this.props.periode) + 2}`,
            options: {
                customHeadRender: (columnMeta) => (
                    <th  style={{ ...style2, backgroundColor: '#37b5e6', color: '#fff', fontSize: 13, fontWeight: 1, width: 150, borderRight: "1px solid rgb(255, 255, 255)" }} >
                        {/* <TableCell style={{ ...style2, top: 0, zIndex: 99, backgroundColor: '#1c71b8', width: 96 }}>
                            <Typography style={{ color: 'white', fontSize: 12, fontWeight: 'bold', textAlign: 'center' }}>{columnMeta.name}</Typography>
                        </TableCell> */}
                        <div style={{ borderBottom: "1px #fff solid", textAlign: 'center', fontSize: 12, fontWeight: 'bold', padding: 5 }}>{columnMeta.name}</div>
                        <div className="grid grid-3x" style={{ ...style2, backgroundColor: '#37b5e6', color: '#fff', fontSize: 12, fontWeight: 'bold', position: "sticky" }}>
                            <div className="column-1" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Commercial) MTD"}</span>
                            </div>
                            <div className="column-2" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Fiscal Correction Positive /(Negative)"}</span>
                            </div>
                            <div className="column-3" style={{ placeSelf: 'center', textAlign: 'center', padding: 5 }}>
                                <span>{"Trial Balance (Fiscal) MTD"}</span>
                            </div>
                        </div>
                    </th>
                ),
                setCellProps: () => ({ style2 }),
                customBodyRender: (value, tableMeta, updateValue) => {
                    // console.log(value)
                    return (
                        <div>
                            <div className="grid grid-3x content-center">
                                <div className="col-1">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[1] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbc}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbc).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 0)
                                                                console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[1] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[1] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[1] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[1] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[1] === 1 ?
                                                                // value[0] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[0])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-2">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[2] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.fcp}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.fcp).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 1)
                                                                console.log(dataTable2)
                                                                // console.log(event.target.value)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[2] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[2] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[2] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[2] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[2] === 1 ?
                                                                // value[1] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value.fcp)}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                                <div className="col-3">
                                    <div style={{ textAlign: 'right' }}>
                                        {tableMeta.rowData[3] === 3 ?
                                            <div style={{ flex: 1 }}>
                                                <FormControlLabel
                                                    style={{ margin: 0 }}
                                                    value={value.tbf}
                                                    control={
                                                        <NumberFormat
                                                            thousandSeparator={true}
                                                            style={{ color: "#5198ea", fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                            type="text"
                                                            placeholder="input"
                                                            disabled={this.props.isApprover}
                                                            value={Number(value.tbf).toFixed(1)}
                                                            onBlur={(event) => {
                                                                // updateValue(event.target.value)
                                                                handleChange(event.target.value, tableMeta, 2)
                                                                console.log(dataTable2)
                                                            }}
                                                        />
                                                    }
                                                />
                                            </div> :
                                            tableMeta.rowData[3] === 2 ?
                                                <span style={{ fontSize: 12, textAlign: 'right' }}>
                                                    <NumberFormat
                                                        thousandSeparator={true}
                                                        style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        type="text"
                                                        placeholder=""
                                                        disabled={true}
                                                        // value={Number(handleValue(tableMeta)).toFixed(1)}
                                                    />
                                                </span>
                                                :
                                                tableMeta.rowData[3] === 4 ?
                                                    null
                                                    :
                                                    tableMeta.rowData[3] === 6 ?
                                                        // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                        :
                                                        tableMeta.rowData[3] === 5 ?
                                                            // <NumberFormat
                                                        //     thousandSeparator={true}
                                                        //     style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                        //     type="text"
                                                        //     placeholder=""
                                                        //     disabled={true}
                                                        //     value={Number(handleFormula(value, tableMeta)).toFixed(1)}
                                                        // />
                                                        null
                                                            :
                                                            tableMeta.rowData[3] === 1 ?
                                                                // value[2] === "" ?
                                                                //     null :
                                                                //     <NumberFormat
                                                                //         thousandSeparator={true}
                                                                //         style={{ fontSize: 12, textAlign: 'right', borderColor: 'transparent', margin: 0, width: 96, backgroundColor: 'transparent' }}
                                                                //         type="text"
                                                                //         placeholder=""
                                                                //         disabled={true}
                                                                //         value={Number(value[2])}
                                                                //     />
                                                                null
                                                                :
                                                                null
                                        }
                                    </div>
                                </div>
                            </div>
                        </div>
                    )
                }
            }
        }
        ]
        const loadingComponent = (
            <div style={{ position: 'absolute', zIndex: 110, top: 0, left: 0, width: '100%', height: '100%', display: 'flex', justifyContent: 'center', alignItems: 'center', background: 'rgba(255,255,255,0.8)' }}>
                <PropagateLoader
                    // css={override}
                    size={20}
                    color={"#274B80"}
                    loading={this.state.loading}
                />
            </div>
        );

        return (
            <div style={{ height: this.props.height, backgroundColor: '#f8f8f8', marginBottom: 100, minHeight: 1000 }}>
                <div className={"main-color"} style={{ height: 78, flex: 1, display: 'flex', alignItems: 'center', paddingLeft: 20 }}>
                    <Typography style={{ fontSize: '16px', color: 'white' }}>Master Budget Submission</Typography>
                </div>
                <Snackbar open={this.state.alert} autoHideDuration={6000} onClose={() => this.closeAlert()}>
                    <Alert onClose={() => this.closeAlert()} severity={this.state.tipeAlert}>
                        {this.state.messageAlert}
                    </Alert>
                </Snackbar>
                {/* {this.state.loading && loadingComponent} */}
                <div style={{ flex: 1, padding: 20, width: '100%' }}>
                    {this.state.visibleTP === true ?
                        <Paper style={{ paddingTop: 10, paddingBottom: 20 }}>
                            <div style={{ borderBottom: 'solid 1px #c4c4c4' }} >
                                <Typography style={{ fontSize: '12px', color: '#4b4b4b', margin: 10 }}>Master Budget - Tax Planning</Typography>
                            </div>
                            <div style={{ padding: 20 }}>
                                <div style={{ display: 'flex', justifyContent: 'space-between' }}>
                                    <div>
                                        <Typography style={{ fontSize: '11px', color: '#4b4b4b' }}>{this.props.company.company_name}</Typography>
                                        <Typography style={{ fontSize: '11px', color: '#4b4b4b' }}>Periode : {this.props.periode}</Typography>
                                        <Typography style={{ fontSize: '11px', color: '#4b4b4b' }}>in IDR mn</Typography>
                                    </div>
                                    <div style={{ width: '50%' }}>
                                    {this.props.isApprover == true ? null :
                                        <div style={{ justifyContent: 'flex-end', display: 'flex', flexFlow: 'wrap' }}>
                                            <a data-tip={'Download Template'} data-for="template">
                                                <button
                                                    style={{
                                                        backgroundColor: 'transparent',
                                                        cursor: 'pointer',
                                                        borderColor: 'transparent',
                                                        margin: 5
                                                    }}
                                                    onClick={() => this.downloadTemplate()}
                                                >
                                                    <img src={Images.template} />
                                                </button>
                                            </a>
                                            <ReactTooltip border={true} id="template" place="bottom" type="light" effect="solid" />
                                            <a data-tip={'Upload'} data-for="upload">
                                                <button
                                                    style={{
                                                        backgroundColor: 'transparent',
                                                        cursor: 'pointer',
                                                        borderColor: 'transparent',
                                                        margin: 5
                                                    }}
                                                    onClick={() => this.setState({ visibleUpload: true })}
                                                >
                                                    <img src={Images.upload} />
                                                </button>
                                            </a>
                                            <ReactTooltip border={true} id="upload" place="bottom" type="light" effect="solid" />
                                            <a data-tip={'Download'} data-for="download">
                                                <button
                                                    style={{
                                                        backgroundColor: 'transparent',
                                                        cursor: 'pointer',
                                                        borderColor: 'transparent',
                                                        margin: 5
                                                    }}
                                                    onClick={() => 
                                                        this.setState({ loading: true }, () => {
                                                            setTimeout(() => {
                                                                this.downloadAllData()
                                                            }, 100);
                                                        })}
                                                >
                                                    <img src={Images.download} />
                                                </button>
                                            </a>
                                            <ReactTooltip border={true} id="download" place="bottom" type="light" effect="solid" />
                                        </div>
                                    }
                                    </div>
                                </div>

                                <div style={{ marginTop: 20, width: this.props.width - (this.props.open === true ? 400 : 150) }}>
                                {this.state.loading && loadingComponent}
                                    <MuiThemeProvider theme={getMuiTheme()}>
                                        <MUIDataTable
                                            data={dataTable2}
                                            columns={columns}
                                            options={options}
                                        />
                                    </MuiThemeProvider>
                                </div>
                                <Typography style={{ fontSize: '11px', color: '#4b4b4b', marginTop: 20 }}>Last Updated by : {this.state.updateBy}</Typography>
                            </div>
                            <div className="grid grid-2x" style={{ marginTop: 20 }}>
                                <div className="col-1">
                                    <button
                                        type="button"
                                        onClick={() => this.setState({ loading: true }, () => {
                                            setTimeout(() => {
                                                this.props.onClickClose()
                                            }, 100);
                                        })}
                                        style={{
                                            backgroundColor: 'transparent',
                                            cursor: 'pointer',
                                            borderColor: 'transparent',
                                            outline: 'none'
                                        }}
                                    >
                                        <div style={{ backgroundColor: '#019ce5', width: 105, height: 25, borderRadius: 3, justifyContent: 'center', display: 'flex', alignItems: 'center' }}>
                                            <Typography style={{ fontSize: '11px', color: '#fff', textAlign: 'center' }}>Cancel</Typography>
                                        </div>
                                    </button>
                                </div>
                                {this.props.isApprover === true ? null :
                                <div className="col-2" style={{ display: 'flex', justifyContent: 'flex-end', maxWidth: '100%' }}>
                                    <button
                                        className="button"
                                        type="button"
                                        style={{
                                            backgroundColor: 'transparent',
                                            cursor: 'pointer',
                                            borderColor: 'transparent',
                                            outline: 'none',
                                            marginRight: 20
                                        }}
                                        onClick={() => {
                                            // this.forceUpdate()
                                            this.setState({ loading: true, buttonDraft: false }, () => {
                                                setTimeout(() => {
                                                    // this.setState({ loading: false, buttonError: false, editable: true })
                                                    this.handleValidate()
                                                }, 100);
                                            })
                                        }}
                                    >
                                        <div style={{ backgroundColor: '#fff', width: 105, height: 25, borderRadius: 3, justifyContent: 'center', display: 'flex', alignItems: 'center', border: 'solid 1px #354960' }}>
                                            <Typography style={{ fontSize: '11px', color: '#354960', textAlign: 'center' }}>Calculate</Typography>
                                        </div>
                                    </button>
                                    <button
                                        className="button"
                                        type="button"
                                        disabled={this.state.buttonDraft}
                                        // onClick={() => this.state.editable === true ?
                                        //     null :
                                        //     this.setState({ loading: true }, () => {
                                        //         setTimeout(() => {
                                        //             this.backToMasterBudget('draft')
                                        //         }, 100);
                                        //     })
                                        // }
                                        onClick={() => 
                                            this.state.handleTekTekTek == 1? null :
                                            this.setState({handleTekTekTek: 1}, () => {
                                                this.backToMasterBudget('draft')
                                            })
                                        }
                                        style={{
                                            backgroundColor: 'transparent',
                                            cursor: this.state.editable !== true ? 'pointer' : 'default',
                                            borderColor: 'transparent',
                                            outline: 'none',
                                            marginRight: 20
                                        }}
                                    >
                                        <div style={{ backgroundColor: '#354960', width: 105, height: 25, borderRadius: 3, justifyContent: 'center', display: 'flex', alignItems: 'center' }}>
                                            <Typography style={{ fontSize: '11px', color: '#fff', textAlign: 'center' }}>Save as Draft</Typography>
                                        </div>
                                    </button>
                                    
                                    <button
                                        type="button"
                                        disabled={this.state.buttonError}
                                        // onClick={() => {
                                        //     this.state.buttonError ?
                                        //         this.setState({ loading: true }, () => {
                                        //             setTimeout(() => {
                                        //                 this.setState({ alert: true, messageAlert: 'Data is not complete !', tipeAlert: 'warning', loading: false })
                                        //             }, 100);
                                        //         })
                                        //         : this.setState({ loading: true }, () => {
                                        //             this.backToMasterBudget('submitted')
                                        //         })
                                        // }}
                                        onClick={() => this.state.buttonError? 
                                            this.setState({ alert: true, messageAlert: 'Data is not complete !', tipeAlert: 'warning' }) 
                                            : 
                                            this.state.handleTekTekTek == 1? null :
                                            this.setState({handleTekTekTek: 1}, () => {
                                                this.backToMasterBudget('submitted')
                                            })}
                                        style={{
                                            backgroundColor: 'transparent',
                                            cursor: this.state.buttonError === true ? 'default' : 'pointer',
                                            borderColor: 'transparent',
                                            outline: 'none'
                                        }}
                                    >
                                        <div style={{ backgroundColor: '#354960', width: 105, height: 25, borderRadius: 3, justifyContent: 'center', display: 'flex', alignItems: 'center', marginRight: 20 }}>
                                            <Typography style={{ fontSize: '11px', color: '#fff', textAlign: 'center' }}>Save & Complete</Typography>
                                        </div>
                                    </button>
                                </div>
                                }
                            </div>
                        </Paper>
                    :
                        <Paper style={{ paddingTop: 10, paddingBottom: 20 }}>
                            <div>
                                <div style={{ padding: 25 }}>
                                    <div>
                                        <Typography style={{ fontSize: '11px', color: '#4b4b4b' }}>{this.props.company.company_name}</Typography>
                                        <Typography style={{ fontSize: '11px', color: '#4b4b4b' }}>Period : {this.props.periode}</Typography>
                                        <Typography style={{ fontSize: '11px', color: '#4b4b4b' }}>in IDR mn</Typography>
                                    </div>
                                    {this.state.dataLoaded && (
                                        <div style={{ marginTop: 20, width: this.props.width - (this.props.open === true ? 400 : 150) }}>
                                            {this.state.loading && loadingComponent}
                                            <MuiThemeProvider theme={getMuiTheme()}>
                                                <MUIDataTable
                                                    data={dataTable2}
                                                    columns={columns}
                                                    options={options}
                                                />
                                            </MuiThemeProvider>
                                        </div>
                                    )}
                                </div>
                                <div className="grid grid-2x" style={{ marginTop: 20 }}>
                                    <div className="col-1">
                                        <button
                                            type="button"
                                            onClick={() => this.setState({ loading: true, visibleTP: true }, () => {
                                                setTimeout(() => {
                                                    this.getItemHierarki()
                                                }, 100);
                                            })}
                                            style={{ marginRight: 20 }}
                                        >
                                            <div style={{ backgroundColor: '#019ce5', width: 105, height: 25, borderRadius: 3, justifyContent: 'center', display: 'flex', alignItems: 'center' }}>
                                                <Typography style={{ fontSize: '11px', color: '#fff', textAlign: 'center' }}>Cancel</Typography>
                                            </div>
                                        </button>
                                    </div>
                                    <div className="col-2" style={{ display: 'flex', justifyContent: 'flex-end', maxWidth: '100%' }}>
                                        <button
                                            className="button"
                                            type="button"
                                            disabled={this.state.buttonError}
                                            style={{
                                                backgroundColor: 'transparent',
                                                cursor: this.state.buttonError === true ? 'default' : 'pointer',
                                                borderColor: 'transparent',
                                                outline: 'none',
                                                marginRight: 20
                                            }}
                                            onClick={() => {
                                                this.setState({ loading: true }, () => {
                                                    setTimeout(() => {
                                                        this.setState({ loading: false, buttonError: this.state.errorPreview === true ? true : false, editable: false })
                                                    }, 100);
                                                })
                                            }}
                                        >
                                            <div style={{ backgroundColor: '#fff', width: 105, height: 25, borderRadius: 3, justifyContent: 'center', display: 'flex', alignItems: 'center', border: 'solid 1px #354960' }}>
                                                <Typography style={{ fontSize: '11px', color: '#354960', textAlign: 'center' }}>Calculate</Typography>
                                            </div>
                                        </button>
                                        <button
                                            type="button"
                                            // disabled={this.state.buttonError}
                                            style={{
                                                backgroundColor: 'transparent',
                                                cursor: this.state.editable !== true ? 'pointer' : 'default',
                                                borderColor: 'transparent',
                                                outline: 'none',
                                                marginRight: 20
                                            }}
                                            onClick={() => 
                                                this.state.editable === true ?
                                                    null :
                                                    this.state.handleTekTekTek == 1 ? null :
                                                        this.setState({ handleTekTekTek: 1 }, () => {
                                                            setTimeout(() => {
                                                                this.uploadTP('draft')
                                                            }, 100);
                                                        })
                                            }
                                        >
                                            <div style={{ backgroundColor: '#354960', width: 105, height: 25, borderRadius: 3, justifyContent: 'center', display: 'flex', alignItems: 'center' }}>
                                                <Typography style={{ fontSize: '11px', color: '#fff', textAlign: 'center' }}>Save as Draft</Typography>
                                            </div>
                                        </button>
                                        <button
                                            type="button"
                                            // disabled={this.state.buttonError}
                                            style={{
                                                backgroundColor: 'transparent',
                                                cursor: this.state.editable !== true ? 'pointer' : 'default',
                                                borderColor: 'transparent',
                                                outline: 'none',
                                            }}
                                            onClick={() => 
                                                this.state.editable === true ?
                                                    null :
                                                    this.state.handleTekTekTek == 1 ? null :
                                                        this.setState({ handleTekTekTek: 1 }, () => {
                                                            setTimeout(() => {
                                                                this.uploadTP('submitted')
                                                            }, 100);
                                                        })
                                            }
                                        >
                                            <div style={{ backgroundColor: '#354960', width: 105, height: 25, borderRadius: 3, justifyContent: 'center', display: 'flex', alignItems: 'center' }}>
                                                <Typography style={{ fontSize: '11px', color: '#fff', textAlign: 'center' }}>Save & Complete</Typography>
                                            </div>
                                        </button>
                                    </div>
                                </div>
                            </div>
                        </Paper>
                    }
                </div>
                {this.state.visibleUpload && (
                    <div className="test app-popup-show">
                        <div className="popup-content background-white border-radius" style={{ borderRadius: 8 }}>
                            <div className="popup-panel grid grid-2x main-color" style={{ height: 64, borderTopRightRadius: 8, borderTopLeftRadius: 8 }}>
                                <div className="col-1" style={{ maxWidth: "inherit", display: 'flex', alignItems: 'center' }}>
                                    <div className="popup-title">
                                        <span style={{ color: '#fff', fontSize: 16, fontWeight: 'bold' }}>Upload File</span>
                                    </div>
                                </div>
                                <div className="col-2 content-right" style={{ maxWidth: "inherit", alignSelf: 'center' }}>
                                    <button
                                        type="button"
                                        className="btn btn-circle btn-white"
                                        onClick={() => this.setState({ visibleUpload: false })}
                                    >
                                        <img src={Images.close} />
                                    </button>
                                </div>
                            </div>
                            <UploadFile
                                type={this.state.uploadStatus}
                                percentage={this.state.percentage}
                                result={this.state.result}
                                acceptedFiles={["xlsx"]}
                                onHandle={(dt) => {
                                    this.fileHandler(dt)
                                    this.setState({ uploadStatus: 'idle', percentage: '0' })
                                }}
                                onUpload={() => {
                                    this.state.judul === "MASTER BUDGET - TAX PLANNING" ?
                                        this.checkUpload() :
                                        this.setState({ alert: true, messageAlert: "Invalid Template", tipeAlert: 'warning' })
                                }}
                            />
                        </div>
                    </div>
                )}
            </div>
        );
    }
}
